@@ -26,10 +26,7 @@ class DisabledSdist(sdist):
 
 
 def main():
-    try:
-        from setuptools import setup
-    except ImportError:
-        from distutils.core import setup
+    from setuptools import setup
 
     # Make sure the to-be-installed version of Twisted is used, if available,
     # since we're importing from it:
@@ -47,6 +44,7 @@ def main():
     args['data_files'] = getDataFiles('twisted') + _dataFiles
     args['zip_safe'] = False
     args['cmdclass'] = {'sdist': DisabledSdist}
+    args['scripts'] = ['bin/trial']
 
     setup(**args)
 
