@@ -129,7 +129,7 @@ class SSHTransportBase(protocol.Protocol):
 
     @ivar isClient: A boolean indicating whether this is a client or server.
 
-    @ivar gotVersion: A boolean indicating whether we have receieved the
+    @ivar gotVersion: A boolean indicating whether we have received the
         version string from the other side.
 
     @ivar buf: Data we've received but hasn't been parsed into a packet.
@@ -614,14 +614,14 @@ class SSHTransportBase(protocol.Protocol):
 
     def ssh_IGNORE(self, packet):
         """
-        Called when we receieve a MSG_IGNORE message.  No payload.
+        Called when we receive a MSG_IGNORE message.  No payload.
         This means nothing; we simply return.
         """
 
 
     def ssh_UNIMPLEMENTED(self, packet):
         """
-        Called when we receieve a MSG_UNIMPLEMENTED message.  Payload::
+        Called when we receive a MSG_UNIMPLEMENTED message.  Payload::
             long packet
 
         This means that the other side did not implement one of our packets.
@@ -632,7 +632,7 @@ class SSHTransportBase(protocol.Protocol):
 
     def ssh_DEBUG(self, packet):
         """
-        Called when we receieve a MSG_DEBUG message.  Payload::
+        Called when we receive a MSG_DEBUG message.  Payload::
             bool alwaysDisplay
             string message
             string language
@@ -1213,7 +1213,7 @@ class SSHClientTransport(SSHTransportBase):
 
     def ssh_KEX_DH_GEX_REPLY(self, packet):
         """
-        Called when we receieve a MSG_KEX_DH_GEX_REPLY message.  Payload::
+        Called when we receive a MSG_KEX_DH_GEX_REPLY message.  Payload::
             string server host key
             integer f (server DH public key)
 
@@ -1278,9 +1278,9 @@ class SSHClientTransport(SSHTransportBase):
 
     def ssh_NEWKEYS(self, packet):
         """
-        Called when we receieve a MSG_NEWKEYS message.  No payload.
+        Called when we receive a MSG_NEWKEYS message.  No payload.
         If we've finished setting up our own keys, start using them.
-        Otherwise, remeber that we've receieved this message.
+        Otherwise, remember that we've received this message.
         """
         if packet != '':
             self.sendDisconnect(DISCONNECT_PROTOCOL_ERROR,
@@ -1295,7 +1295,7 @@ class SSHClientTransport(SSHTransportBase):
 
     def ssh_SERVICE_ACCEPT(self, packet):
         """
-        Called when we receieve a MSG_SERVICE_ACCEPT message.  Payload::
+        Called when we receive a MSG_SERVICE_ACCEPT message.  Payload::
             string service name
 
         Start the service we requested.
@@ -1367,7 +1367,7 @@ class SSHCiphers:
     to encrypt and authenticate the SSH connection.
 
     @cvar cipherMap: A dictionary mapping SSH encryption names to 3-tuples of
-                     (<Crypto.Cipher.* name>, <block size>, <counter mode>)
+                     (<Crypto.Cipher.* name>, <block size>, <is counter mode>)
     @cvar macMap: A dictionary mapping SSH MAC names to hash modules.
 
     @ivar outCipType: the string type of the outgoing cipher.
@@ -1383,19 +1383,19 @@ class SSHCiphers:
     """
 
     cipherMap = {
-        '3des-cbc':('DES3', 24, 0),
-        'blowfish-cbc':('Blowfish', 16,0 ),
-        'aes256-cbc':('AES', 32, 0),
-        'aes192-cbc':('AES', 24, 0),
-        'aes128-cbc':('AES', 16, 0),
-        'cast128-cbc':('CAST', 16, 0),
-        'aes128-ctr':('AES', 16, 1),
-        'aes192-ctr':('AES', 24, 1),
-        'aes256-ctr':('AES', 32, 1),
-        '3des-ctr':('DES3', 24, 1),
-        'blowfish-ctr':('Blowfish', 16, 1),
-        'cast128-ctr':('CAST', 16, 1),
-        'none':(None, 0, 0),
+        '3des-cbc': ('DES3', 24, False),
+        'blowfish-cbc': ('Blowfish', 16, False),
+        'aes256-cbc': ('AES', 32, False),
+        'aes192-cbc': ('AES', 24, False),
+        'aes128-cbc': ('AES', 16, False),
+        'cast128-cbc': ('CAST', 16, False),
+        'aes128-ctr': ('AES', 16, True),
+        'aes192-ctr': ('AES', 24, True),
+        'aes256-ctr': ('AES', 32, True),
+        '3des-ctr': ('DES3', 24, True),
+        'blowfish-ctr': ('Blowfish', 16, True),
+        'cast128-ctr': ('CAST', 16, True),
+        'none': (None, 0, False),
     }
     macMap = {
         'hmac-sha1': sha1,
