@@ -23,33 +23,25 @@ from socket import AF_INET6, AF_INET
 
 from zope.interface import implementer, directlyProvides
 
-from twisted.python.compat import _PY3
 from twisted.internet import interfaces, defer, error, fdesc, threads
-from twisted.internet.protocol import ClientFactory, Factory
-from twisted.internet.protocol import ProcessProtocol, Protocol
+from twisted.internet.abstract import isIPv6Address
+from twisted.internet.address import _ProcessAddress, HostnameAddress
 from twisted.internet.interfaces import (
     IStreamServerEndpointStringParser, IStreamClientEndpointStringParser,
     IStreamClientEndpointStringParserWithReactor)
+from twisted.internet.protocol import ClientFactory, Factory
+from twisted.internet.protocol import ProcessProtocol, Protocol
+from twisted.internet.stdio import StandardIO, PipeAddress
+from twisted.internet.task import LoopingCall
+from twisted.plugin import IPlugin, getPlugins
+from twisted.python import log
+from twisted.python.compat import nativeString
+from twisted.python.components import proxyForInterface
+from twisted.python.constants import NamedConstant, Names
+from twisted.python.failure import Failure
 from twisted.python.filepath import FilePath
 from twisted.python.systemd import ListenFDs
-from twisted.internet.abstract import isIPv6Address
-from twisted.python.failure import Failure
-from twisted.python import log
-from twisted.internet.address import _ProcessAddress, HostnameAddress
-from twisted.python.components import proxyForInterface
-from twisted.internet.task import LoopingCall
 
-if not _PY3:
-    from twisted.plugin import IPlugin, getPlugins
-    from twisted.internet.stdio import StandardIO, PipeAddress
-    from twisted.python.constants import NamedConstant, Names
-else:
-    from zope.interface import Interface
-    class IPlugin(Interface):
-        pass
-    NamedConstant = object
-    Names = object
-    StandardIO = None
 
 __all__ = ["clientFromString", "serverFromString",
            "TCP4ServerEndpoint", "TCP6ServerEndpoint",
@@ -60,12 +52,6 @@ __all__ = ["clientFromString", "serverFromString",
            "ProcessEndpoint", "HostnameEndpoint",
            "StandardErrorBehavior", "connectProtocol"]
 
-__all3__ = ["TCP4ServerEndpoint", "TCP6ServerEndpoint",
-            "TCP4ClientEndpoint", "TCP6ClientEndpoint",
-            "SSL4ServerEndpoint", "SSL4ClientEndpoint",
-            "UNIXServerEndpoint", "UNIXClientEndpoint",
-            "connectProtocol", "HostnameEndpoint",
-            "ProcessEndpoint", "StandardErrorBehavior"]
 
 
 class _WrappingProtocol(Protocol):
@@ -1099,12 +1085,12 @@ def _parseSSL(factory, port, privateKey="server.pem", certKey=None,
     @param extraCertChain: The path of a file containing one or more
         certificates in PEM format that establish the chain from a root CA to
         the CA that signed your C{certKey}.
-    @type extraCertChain: L{bytes}
+    @type extraCertChain: L{str}
 
     @param dhParameters: The file name of a file containing parameters that are
         required for Diffie-Hellman key exchange.  If this is not specified,
         the forward secret C{DHE} ciphers aren't available for servers.
-    @type dhParameters: L{bytes}
+    @type dhParameters: L{str}
 
     @return: a 2-tuple of (args, kwargs), describing  the parameters to
         L{IReactorSSL.listenSSL} (or, modulo argument 2, the factory, arguments
@@ -1120,9 +1106,10 @@ def _parseSSL(factory, port, privateKey="server.pem", certKey=None,
     keyPEM = FilePath(privateKey).getContent()
     privateCertificate = ssl.PrivateCertificate.loadPEM(certPEM + keyPEM)
     if extraCertChain is not None:
+        extraCertChain = FilePath(extraCertChain).getContent()
         matches = re.findall(
             r'(-----BEGIN CERTIFICATE-----\n.+?\n-----END CERTIFICATE-----)',
-            FilePath(extraCertChain).getContent(),
+            nativeString(extraCertChain),
             flags=re.DOTALL
         )
         chainCertificates = [ssl.Certificate.loadPEM(chainCertPEM).original
@@ -1301,7 +1288,7 @@ def _tokenize(description):
             current = ''
             ops = nextOps[n]
         elif n == '\\':
-            current += description.next()
+            current += next(description)
         else:
             current += n
     yield _STRING, current
@@ -1430,20 +1417,20 @@ def serverFromString(reactor, description):
     For example, you can call it like this to create an endpoint that will
     listen on TCP port 80::
 
-        serverFromString(reactor, b"tcp:80")
+        serverFromString(reactor, "tcp:80")
 
     Additional arguments may be specified as keywords, separated with colons.
     For example, you can specify the interface for a TCP server endpoint to
     bind to like this::
 
-        serverFromString(reactor, b"tcp:80:interface=127.0.0.1")
+        serverFromString(reactor, "tcp:80:interface=127.0.0.1")
 
     SSL server endpoints may be specified with the 'ssl' prefix, and the
     private key and certificate files may be specified by the C{privateKey} and
     C{certKey} arguments::
 
         serverFromString(
-            reactor, b"ssl:443:privateKey=key.pem:certKey=crt.pem")
+            reactor, "ssl:443:privateKey=key.pem:certKey=crt.pem")
 
     If a private key file name (C{privateKey}) isn't provided, a "server.pem"
     file is assumed to exist which contains the private key. If the certificate
@@ -1454,14 +1441,14 @@ def serverFromString(reactor, description):
     use if you want to specify a full pathname argument on Windows::
 
         serverFromString(reactor,
-            b"ssl:443:privateKey=C\\:/key.pem:certKey=C\\:/cert.pem")
+            "ssl:443:privateKey=C\\:/key.pem:certKey=C\\:/cert.pem")
 
     finally, the 'unix' prefix may be used to specify a filesystem UNIX socket,
     optionally with a 'mode' argument to specify the mode of the socket file
     created by C{listen}::
 
-        serverFromString(reactor, b"unix:/var/run/finger")
-        serverFromString(reactor, b"unix:/var/run/finger:mode=660")
+        serverFromString(reactor, "unix:/var/run/finger")
+        serverFromString(reactor, "unix:/var/run/finger:mode=660")
 
     This function is also extensible; new endpoint types may be registered as
     L{IStreamServerEndpointStringParser} plugins.  See that interface for more
@@ -1470,7 +1457,7 @@ def serverFromString(reactor, description):
     @param reactor: The server endpoint will be constructed with this reactor.
 
     @param description: The strports description to parse.
-    @type description: L{bytes}
+    @type description: L{str}
 
     @return: A new endpoint which can be used to listen with the parameters
         given by C{description}.
@@ -1492,7 +1479,7 @@ def quoteStringArgument(argument):
     backslashes, some care is necessary if, for example, you have a pathname,
     you may be tempted to interpolate into a string like this::
 
-        serverFromString(reactor, b"ssl:443:privateKey=%s" % (myPathName,))
+        serverFromString(reactor, "ssl:443:privateKey=%s" % (myPathName,))
 
     This may appear to work, but will have portability issues (Windows
     pathnames, for example).  Usually you should just construct the appropriate
@@ -1502,19 +1489,19 @@ def quoteStringArgument(argument):
     configuration file which has strports descriptions in it.  To be correct in
     those cases, do this instead::
 
-        serverFromString(reactor, b"ssl:443:privateKey=%s" %
+        serverFromString(reactor, "ssl:443:privateKey=%s" %
                          (quoteStringArgument(myPathName),))
 
     @param argument: The part of the endpoint description string you want to
         pass through.
 
-    @type argument: C{bytes}
+    @type argument: C{str}
 
     @return: The quoted argument.
 
-    @rtype: C{bytes}
+    @rtype: C{str}
     """
-    return argument.replace(b'\\', b'\\\\').replace(b':', b'\\:')
+    return argument.replace('\\', '\\\\').replace(':', '\\:')
 
 
 
@@ -1686,35 +1673,35 @@ def clientFromString(reactor, description):
     You can create a TCP client endpoint with the 'host' and 'port' arguments,
     like so::
 
-        clientFromString(reactor, b"tcp:host=www.example.com:port=80")
+        clientFromString(reactor, "tcp:host=www.example.com:port=80")
 
     or, without specifying host and port keywords::
 
-        clientFromString(reactor, b"tcp:www.example.com:80")
+        clientFromString(reactor, "tcp:www.example.com:80")
 
     Or you can specify only one or the other, as in the following 2 examples::
 
-        clientFromString(reactor, b"tcp:host=www.example.com:80")
-        clientFromString(reactor, b"tcp:www.example.com:port=80")
+        clientFromString(reactor, "tcp:host=www.example.com:80")
+        clientFromString(reactor, "tcp:www.example.com:port=80")
 
     or an SSL client endpoint with those arguments, plus the arguments used by
     the server SSL, for a client certificate::
 
-        clientFromString(reactor, b"ssl:web.example.com:443:"
-                                  b"privateKey=foo.pem:certKey=foo.pem")
+        clientFromString(reactor, "ssl:web.example.com:443:"
+                                  "privateKey=foo.pem:certKey=foo.pem")
 
     to specify your certificate trust roots, you can identify a directory with
     PEM files in it with the C{caCertsDir} argument::
 
-        clientFromString(reactor, b"ssl:host=web.example.com:port=443:"
-                                  b"caCertsDir=/etc/ssl/certs")
+        clientFromString(reactor, "ssl:host=web.example.com:port=443:"
+                                  "caCertsDir=/etc/ssl/certs")
 
     Both TCP and SSL client endpoint description strings can include a
     'bindAddress' keyword argument, whose value should be a local IPv4
     address. This fixes the client socket to that IP address::
 
-        clientFromString(reactor, b"tcp:www.example.com:80:"
-                                  b"bindAddress=192.0.2.100")
+        clientFromString(reactor, "tcp:www.example.com:80:"
+                                  "bindAddress=192.0.2.100")
 
     NB: Fixed client ports are not currently supported in TCP or SSL
     client endpoints. The client socket will always use an ephemeral
@@ -1729,8 +1716,8 @@ def clientFromString(reactor, description):
     or, with the path as a positional argument with or without optional
     arguments as in the following 2 examples::
 
-        clientFromString(reactor, b"unix:/var/foo/bar")
-        clientFromString(reactor, b"unix:/var/foo/bar:lockfile=1:timeout=9")
+        clientFromString(reactor, "unix:/var/foo/bar")
+        clientFromString(reactor, "unix:/var/foo/bar:lockfile=1:timeout=9")
 
     This function is also extensible; new endpoint types may be registered as
     L{IStreamClientEndpointStringParserWithReactor} plugins.  See that
@@ -1739,7 +1726,7 @@ def clientFromString(reactor, description):
     @param reactor: The client endpoint will be constructed with this reactor.
 
     @param description: The strports description to parse.
-    @type description: L{bytes}
+    @type description: L{str}
 
     @return: A new endpoint which can be used to connect with the parameters
         given by C{description}.
@@ -1783,12 +1770,3 @@ def connectProtocol(endpoint, protocol):
         def buildProtocol(self, addr):
             return protocol
     return endpoint.connect(OneShotFactory())
-
-
-
-if _PY3:
-    for name in __all__[:]:
-        if name not in __all3__:
-            __all__.remove(name)
-            del globals()[name]
-    del name, __all3__
